@@ -1,16 +1,15 @@
-__version__ = "1.26.0"
+__version__ = "2.0.0"
 __author__ = "Hanjin Liu"
 __email__ = "liuhanjin-sc@g.ecc.u-tokyo.ac.jp"
 
 import logging
-from functools import wraps
 
-from ._const import Const, SetConst, silent, use
+from ._const import Const, SetConst, use
 
 from .collections import *
 from .core import *
 from .binder import bind
-from .viewer import gui, GUIcanvas
+from .viewer import gui
 from .correlation import *
 from .arrays import ImgArray, LazyImgArray  # for typing
 from . import random
@@ -20,11 +19,9 @@ Inheritance
 -----------
         np.ndarray _    _ AxesMixin _
                     \  /             \
-              __ MetaArray _     LazyImgArray
-             /              \ 
-       HistoryArray     PropArray
-       /         \    
-  LabeledArray   Label  
+            ____ MetaArray _     LazyImgArray
+          /        /        \ 
+  LabeledArray  Label    PropArray
     /     \
 ImgArray PhaseArray
 
@@ -34,4 +31,4 @@ logging.getLogger("skimage").setLevel(logging.ERROR)
 logging.getLogger("tifffile").setLevel(logging.ERROR)
 
 
-del logging, wraps
\ No newline at end of file
+del logging
\ No newline at end of file
