@@ -15,7 +15,6 @@ from functools import wraps
 from .utils.io import open_img, open_as_dask, get_scale_from_meta, open_mrc, open_tif
 from .utils import gauss
 from .utils.slicer import *
-from .utils.utilcls import Progress
 from ._types import *
 
 from .axes import ImageAxesError
@@ -24,20 +23,22 @@ from .arrays.bases import MetaArray
 from .arrays import ImgArray, LazyImgArray
 from ._const import Const
 
-__all__ = ["array", 
-           "asarray", 
-           "aslazy", 
-           "zeros", 
-           "empty", 
-           "ones", 
-           "full",
-           "gaussian_kernel", 
-           "circular_mask", 
-           "imread", 
-           "imread_collection", 
-           "lazy_imread", 
-           "read_meta", 
-           "sample_image"]
+__all__ = [
+    "array", 
+    "asarray", 
+    "aslazy", 
+    "zeros", 
+    "empty", 
+    "ones", 
+    "full",
+    "gaussian_kernel", 
+    "circular_mask", 
+    "imread", 
+    "imread_collection", 
+    "lazy_imread", 
+    "read_meta", 
+    "sample_image"
+]
 
 # TODO: 
 # - ip.imread("...\$i$j.tif", key="i=2:"), ip.imread("...\*.tif", key="p=0") will raise error.
@@ -58,12 +59,14 @@ def write_docs(func):
     return func
 
 @write_docs
-def array(arr: ArrayLike,
-          dtype: DTypeLike = None, 
-          *,
-          name: str = None,
-          axes: str = None,
-          copy: bool = True) -> ImgArray:
+def array(
+    arr: ArrayLike,
+    dtype: DTypeLike = None, 
+    *,
+    name: str = None,
+    axes: str = None,
+    copy: bool = True
+) -> ImgArray:
     """
     make an ImgArray object, like ``np.array(x)``
     
@@ -99,11 +102,13 @@ def array(arr: ArrayLike,
     return self
 
 @write_docs
-def asarray(arr: ArrayLike,
-            dtype: DTypeLike = None,
-            *, 
-            name: str = None,
-            axes: str = None) -> ImgArray:
+def asarray(
+    arr: ArrayLike,
+    dtype: DTypeLike = None,
+    *, 
+    name: str = None,
+    axes: str = None
+) -> ImgArray:
     """
     make an ImgArray object, like ``np.asarray(x)``
     
@@ -123,12 +128,14 @@ def asarray(arr: ArrayLike,
     return array(arr, dtype=dtype, name=name, axes=axes, copy=False)
 
 @write_docs
-def aslazy(arr: ArrayLike, 
-           dtype: DTypeLike = None,
-           *, 
-           name: str = None,
-           axes: str = None,
-           chunks="auto") -> LazyImgArray:
+def aslazy(
+    arr: ArrayLike, 
+    dtype: DTypeLike = None,
+    *, 
+    name: str = None,
+    axes: str = None,
+    chunks="auto"
+) -> LazyImgArray:
     """
     Make an LazyImgArray object from other types of array.
     
@@ -309,7 +316,8 @@ def imread(
     dtype: DTypeLike = None,
     key: str = None,
     *, 
-    squeeze: bool = False
+    name: str | None = None,
+    squeeze: bool = False,
 ) -> ImgArray:
     r"""
     Load image(s) from a path. You can read list of images from directories with wildcards or ``"$"``
@@ -325,6 +333,8 @@ def imread(
         If not None, image is read in a memory-mapped array first, and only ``img[key]`` is returned.
         Only axis-targeted slicing is supported. This argument is important when reading a large
         file.
+    name : str, optional
+        Name of array.
     squeeze : bool, default is False
         If True, redundant dimensions will be squeezed.
 
@@ -356,41 +366,27 @@ def imread(
     elif not os.path.exists(path):
         raise FileNotFoundError(f"No such file or directory: {path}")
     
-    fname, fext = os.path.splitext(os.path.basename(path))
-    dirpath = os.path.dirname(path)
-    
     # read tif metadata
-    out = None
     if not is_memmap:
         size = os.path.getsize(path)/1e9
         if size > Const["MAX_GB"]:
             raise MemoryError(f"Too large {size:.2f} GB")
-        elif size > Const["MAX_GB"]/2:
-            out = "stdout"
 
-    with Progress("Reading image", out=out):
-        meta, img = open_img(path, memmap=is_memmap)
+    meta, img = open_img(path, memmap=is_memmap)
 
     axes = meta["axes"]
     metadata = meta["ijmeta"]
-    if meta["history"]:
-        name = meta["history"].pop(0)
-        history = meta["history"]
-    else:
-        name = fname
-        history = []
         
     if is_memmap:
         sl = axis_targeted_slicing(img.ndim, axes, key)
         axes = "".join(a for a, k in zip(axes, sl) if not isinstance(k, int))
         img = np.asarray(img[sl], dtype=dtype)
     
-    self = ImgArray(img, name=name, axes=axes, dirpath=dirpath, 
-                    history=history, metadata=metadata)
+    self = ImgArray(img, name=name, axes=axes, source=path, metadata=metadata)
         
     # In case the image is in yxc-order. This sometimes happens.
     if "c" in self.axes and self.shape.c > self.shape.x:
-        self = np.moveaxis(self, -1, -3)
+        self: ImgArray = np.moveaxis(self, -1, -3)
         _axes = self.axes.axes
         _axes = _axes[:-3] + "cyx"
         self.axes = _axes
@@ -443,7 +439,7 @@ def _imread_glob(path: str, squeeze: bool = False, **kwargs) -> ImgArray:
         out = np.squeeze(out)
     try:
         base = os.path.split(path.split("*")[0])[0]
-        out.dirpath, out.name = os.path.split(base)
+        out.source = base
     except Exception:
         pass
     out.temp = paths
@@ -556,7 +552,7 @@ def _imread_stack(
     self._set_info(imgs[0])
     self.axes = "".join(new_axes) + str(img.axes)
     self.set_scale(imgs[0])
-    # determine dirpath and name
+    # determine source
     name_list = []
     for p in path.split(os.sep):
         if "$" in p or "*" in p:
@@ -564,11 +560,9 @@ def _imread_stack(
         else:
             name_list.append(p)
     if len(name_list) > 0:
-        self.dirpath = os.path.join(*name_list[:-1])
-        self.name = name_list[-1]
+        self.source = os.path.join(*name_list)
     else:
-        self.dirpath = None
-        self.name = None
+        self.source = None
         
     if squeeze:
         self = np.squeeze(self)
@@ -619,7 +613,8 @@ def lazy_imread(
     path: str, 
     chunks="auto",
     *, 
-    squeeze: bool = False
+    name: str | None = None,
+    squeeze: bool = False,
 ) -> LazyImgArray:
     """
     Read an image lazily. Image file is first opened as an memory map, and subsequently converted
@@ -632,6 +627,8 @@ def lazy_imread(
     chunks : optional
         Specify chunk sizes. By default, yx-axes are assigned to the same chunk for every slice of
         image, whild chunk sizes of the rest of axes are automatically set with "auto" option.
+    name : str, optional
+        Name of array.
     squeeze : bool, default is False
         If True and there is one-sized axis, then call `np.squeeze`.
         
@@ -645,26 +642,17 @@ def lazy_imread(
     
     if "*" in path:
         return _lazy_imread_glob(path, chunks=chunks, squeeze=squeeze)
-    fname, fext = os.path.splitext(os.path.basename(path))
-    dirpath = os.path.dirname(path)
     
     # read tif metadata
     meta, img = open_as_dask(path, chunks)
     axes = meta["axes"]
     metadata = meta["ijmeta"]
-    if meta["history"]:
-        name = meta["history"].pop(0)
-        history = meta["history"]
-    else:
-        name = fname
-        history = []
         
     if squeeze:
         axes = "".join(a for i, a in enumerate(axes) if img.shape[i] > 1)
         img = np.squeeze(img)
-        
-    self = LazyImgArray(img, name=name, axes=axes, dirpath=dirpath, 
-                        history=history, metadata=metadata)
+    
+    self = LazyImgArray(img, name=name, axes=axes, source=path, metadata=metadata)
     
     if self.axes.is_none():
         return self
@@ -707,8 +695,7 @@ def _lazy_imread_glob(path: str, squeeze: bool = False, **kwargs) -> LazyImgArra
         out = LazyImgArray(img)
         out._set_info(imgs[0], new_axes=axes)
     try:
-        base = os.path.split(path.split("*")[0])[0]
-        out.dirpath, out.name = os.path.split(base)
+        out.source = os.path.split(path.split("*")[0])[0]
     except Exception:
         pass
     
@@ -730,7 +717,6 @@ def read_meta(path: str) -> dict[str]:
         Dictionary of metadata with following keys.
         - "axes": axes information
         - "ijmeta": ImageJ metadata
-        - "history": impy history
         - "tags": tiff tags
         
     """    
