@@ -1,21 +1,38 @@
 from __future__ import annotations
-from matplotlib import pyplot as plt
 import numpy as np
 from warnings import warn
 from .core import asarray as ip_asarray
 from .arrays import ImgArray, PropArray
 from .arrays._utils import _docs
 from .arrays._utils._transform import polar2d
-from .arrays._utils._corr import subpixel_pcc
+from .arrays._utils._corr import subpixel_pcc, subpixel_ncc, draw_pcc_landscape, draw_ncc_landscape
 from .utils.axesop import complement_axes, add_axes
-from .utils.utilcls import Progress
 from .utils.deco import dims_to_spatial_axes
 from .array_api import xp
 from ._types import Dims
 
-__all__ = ["fsc", "fourier_shell_correlation", "ncc", "zncc", "fourier_ncc", "fourier_zncc",
-           "nmi", "pcc_maximum", "ft_pcc_maximum", "polar_pcc_maximum",
-           "pearson_coloc", "manders_coloc"]
+__all__ = [
+    "fsc",
+    "fourier_shell_correlation",
+    "ncc",
+    "zncc",
+    "fourier_ncc",
+    "fourier_zncc",
+    "nmi",
+    "pcc_maximum",
+    "pcc_maximum_with_corr",
+    "ft_pcc_maximum",
+    "ft_pcc_maximum_with_corr", 
+    "polar_pcc_maximum",
+    "polar_pcc_maximum_with_corr",
+    "zncc_maximum",
+    "zncc_maximum_with_corr",
+    "pcc_landscape", 
+    "ft_pcc_landscape", 
+    "zncc_landscape",
+    "pearson_coloc",
+    "manders_coloc",
+]
 
 @_docs.write_docs
 def fsc(
@@ -57,27 +74,26 @@ def fsc(
     shape = img0.shape
     dims = img0.axes
     
-    freqs = xp.meshgrid(*[xp.fft.fftshift(xp.fft.fftfreq(s)) for s in shape])
+    freqs = xp.meshgrid(*[xp.fft.fftshift(xp.fft.fftfreq(s)) for s in shape], indexing="ij")
     r = xp.sqrt(sum(f**2 for f in freqs))
-    
-    with Progress("fsc"):
-        # make radially separated labels
-        labels = (r/dfreq).astype(np.uint16)
-        nlabels = int(xp.asnumpy(labels.max()))
-        
-        out = xp.empty(nlabels, dtype=np.float32)
-        def radial_sum(arr):
-            arr = xp.asarray(arr)
-            return xp.ndi.sum_labels(arr, labels=labels, index=xp.arange(0, nlabels))
 
-        f0 = img0.fft(dims=dims)
-        f1 = img1.fft(dims=dims)
-        
-        cov = f0.real*f1.real + f0.imag*f1.imag
-        pw0 = f0.real**2 + f0.imag**2
-        pw1 = f1.real**2 + f1.imag**2
+    # make radially separated labels
+    labels = (r/dfreq).astype(np.uint16)
+    nlabels = int(xp.asnumpy(labels.max()))
     
-        out = radial_sum(cov)/xp.sqrt(radial_sum(pw0) * radial_sum(pw1))
+    out = xp.empty(nlabels, dtype=np.float32)
+    def radial_sum(arr):
+        arr = xp.asarray(arr)
+        return xp.ndi.sum_labels(arr, labels=labels, index=xp.arange(0, nlabels))
+
+    f0 = img0.fft(dims=dims)
+    f1 = img1.fft(dims=dims)
+    
+    cov = f0.real*f1.real + f0.imag*f1.imag
+    pw0 = f0.real**2 + f0.imag**2
+    pw1 = f1.real**2 + f1.imag**2
+
+    out = radial_sum(cov)/xp.sqrt(radial_sum(pw0) * radial_sum(pw1))
     freq = (np.arange(len(out)) + 0.5) * dfreq
     return freq, xp.asnumpy(out)
 
@@ -97,9 +113,7 @@ def _ncc(img0: ImgArray, img1: ImgArray, dims: Dims):
     return xp.asnumpy(corr)
 
 
-def _masked_ncc(img0: ImgArray, img1: ImgArray, dims: Dims, mask: ImgArray):
-    if mask.ndim < img0.ndim:
-        mask = add_axes(img0.axes, img0.shape, mask, mask.axes)
+def _masked_ncc(img0: ImgArray, img1: ImgArray, dims: Dims, mask: xp.ndarray):
     n = np.prod(img0.sizesof(dims))
     img0ma = np.ma.array(img0.value, mask=mask)
     img1ma = np.ma.array(img1.value, mask=mask)
@@ -108,22 +122,26 @@ def _masked_ncc(img0: ImgArray, img1: ImgArray, dims: Dims, mask: ImgArray):
         np.ma.std(img0ma, axis=axis)*np.ma.std(img1ma, axis=axis)) / n
 
 
-def _zncc(img0: xp.ndarray, img1: xp.ndarray, dims: Dims):
-    # Basic Zero-Normalized Cross Correlation with batch processing.
+def _zncc(img0: xp.ndarray, img1: xp.ndarray, dims: tuple[int, ...]):
+    # Basic Zero-mean Normalized Cross Correlation with batch processing.
     # Inputs must be already zero-normalized.
     corr = xp.sum(img0 * img1, axis=dims) / (
         xp.sqrt(xp.sum(img0**2, axis=dims)*xp.sum(img1**2, axis=dims)))
     return corr
 
 
-def _masked_zncc(img0: ImgArray, img1: ImgArray, dims: Dims, mask: ImgArray):
-    if mask.ndim < img0.ndim:
-        mask = add_axes(img0.axes, img0.shape, mask, mask.axes)
-    img0ma = np.ma.array(img0.value, mask=mask)
-    img1ma = np.ma.array(img1.value, mask=mask)
-    axis = tuple(img0.axisof(a) for a in dims)
-    return np.sum(img0ma * img1ma, axis=axis) / (
-        np.sqrt(np.sum(img0ma**2, axis=axis)*np.sum(img1ma**2, axis=axis)))
+def _masked_zncc(img0: xp.ndarray, img1: xp.ndarray, dims: tuple[int, ...], mask: ImgArray):
+    if xp.state == "cupy":
+        img0 = img0*mask
+        img1 = img1*mask
+        out = xp.sum(img0*img1, axis=dims) / (
+            xp.sqrt(xp.sum(img0**2, axis=dims)*xp.sum(img1**2, axis=dims)))
+    else:
+        img0ma = np.ma.array(img0, mask=mask)
+        img1ma = np.ma.array(img1, mask=mask)
+        out = np.ma.sum(img0ma * img1ma, axis=dims) / (
+            np.sqrt(np.ma.sum(img0ma**2, axis=dims)*np.ma.sum(img1ma**2, axis=dims)))
+    return out
 
 @_docs.write_docs
 @dims_to_spatial_axes
@@ -152,12 +170,13 @@ def ncc(
     PropArray or float
         Correlation value(s).
     """    
-    with Progress("ncc"):
-        img0, img1 = _check_inputs(img0, img1)
-        if mask is None:
-            corr = _ncc(img0, img1, dims)
-        else:
-            corr = _masked_ncc(img0, img1, dims, mask)
+    img0, img1 = _check_inputs(img0, img1)
+    if mask is None:
+        corr = _ncc(img0, img1, dims)
+    else:
+        if img0.ndim > mask.ndim:
+            mask = add_axes(img0.axes, img0.shape, mask, mask.axes)
+        corr = _masked_ncc(img0, img1, dims, np.asarray(mask))
     return _make_corr_output(corr, img0, "ncc", squeeze, dims)
 
 @_docs.write_docs
@@ -171,7 +190,7 @@ def zncc(
     dims: Dims = None
 ) -> PropArray | float:
     """
-    Zero-Normalized Cross Correlation.
+    Zero-mean Normalized Cross Correlation.
     
     Parameters
     ----------
@@ -187,17 +206,18 @@ def zncc(
     PropArray or float
         Correlation value(s).
     """    
-    with Progress("zncc"):
-        img0, img1 = _check_inputs(img0, img1)
-        dims = tuple(img0.axisof(a) for a in dims)
-        img0 = xp.asarray(img0.value)
-        img1 = xp.asarray(img1.value)
-        img0zn = img0 - xp.mean(img0, axis=dims, keepdims=True)
-        img1zn = img1 - xp.mean(img1, axis=dims, keepdims=True)
-        if mask is None:
-            corr = _zncc(img0zn, img1zn, dims)
-        else:
-            corr = _masked_zncc(img0zn, img1zn, dims, mask)
+    img0, img1 = _check_inputs(img0, img1)
+    _dims = tuple(img0.axisof(a) for a in dims)
+    _img0 = xp.asarray(img0.value)
+    _img1 = xp.asarray(img1.value)
+    img0zn = _img0 - xp.mean(_img0, axis=_dims, keepdims=True)
+    img1zn = _img1 - xp.mean(_img1, axis=_dims, keepdims=True)
+    if mask is None:
+        corr = _zncc(img0zn, img1zn, _dims)
+    else:
+        if img0.ndim > mask.ndim:
+            mask = add_axes(img0.axes, img0.shape, mask, mask.axes)
+        corr = _masked_zncc(img0zn, img1zn, _dims, xp.asarray(np.asarray(mask)))
     return _make_corr_output(xp.asnumpy(corr), img0, "zncc", squeeze, dims)
 
 # alias
@@ -282,14 +302,15 @@ def fourier_ncc(
     PropArray or float
         Correlation value(s).
     """    
-    with Progress("fourier_ncc"):
-        img0, img1 = _check_inputs(img0, img1)
-        f0 = np.sqrt(img0.power_spectra(dims=dims, zero_norm=True))
-        f1 = np.sqrt(img1.power_spectra(dims=dims, zero_norm=True))
-        if mask is None:
-            corr = _ncc(f0, f1, dims)
-        else:
-            corr = _masked_ncc(f0, f1, dims, mask)
+    img0, img1 = _check_inputs(img0, img1)
+    f0 = np.sqrt(img0.power_spectra(dims=dims, zero_norm=True))
+    f1 = np.sqrt(img1.power_spectra(dims=dims, zero_norm=True))
+    if mask is None:
+        corr = _ncc(f0, f1, dims)
+    else:
+        if img0.ndim > mask.ndim:
+            mask = add_axes(img0.axes, img0.shape, mask, mask.axes)
+        corr = _masked_ncc(f0, f1, dims, xp.asarray(np.asarray(mask)))
     return _make_corr_output(corr, img0, "fourier_ncc", squeeze, dims)
 
 @_docs.write_docs
@@ -303,14 +324,14 @@ def fourier_zncc(
     dims: Dims = None
 ) -> PropArray | float:
     """
-    Zero-Normalized Cross Correlation in Fourier space.
+    Zero-mean Normalized Cross Correlation in Fourier space.
     
     Parameters
     ----------
     {inputs_of_correlation}
     mask : boolean ImgArray, optional
-        If provided, True regions will be masked and will not be taken into account when calculate 
-        correlation.
+        If provided, True regions will be masked and will not be taken into account 
+        when calculate correlation.
     {squeeze}
     {dims}
 
@@ -319,21 +340,22 @@ def fourier_zncc(
     PropArray or float
         Correlation value(s).
     """    
-    with Progress("fourier_zncc"):
-        img0, img1 = _check_inputs(img0, img1)
-        dims = tuple(img0.axisof(a) for a in dims)
-        pw0 = xp.asarray(img0.power_spectra(dims=dims, zero_norm=True).value)
-        pw1 = xp.asarray(img1.power_spectra(dims=dims, zero_norm=True).value)
-        
-        f0 = xp.sqrt(pw0)
-        f1 = xp.sqrt(pw1)
-        f0 -= xp.mean(f0, axis=dims, keepdims=True)
-        f1 -= xp.mean(f1, axis=dims, keepdims=True)
-        if mask is None:
-            corr = _zncc(f0, f1, dims)
-        else:
-            corr = _masked_zncc(f0, f1, dims, mask)
-    return _make_corr_output(corr, img0, "fourier_zncc", squeeze, dims)
+    img0, img1 = _check_inputs(img0, img1)
+    pw0 = xp.asarray(img0.power_spectra(dims=dims, zero_norm=True).value)
+    pw1 = xp.asarray(img1.power_spectra(dims=dims, zero_norm=True).value)
+    
+    _dims = tuple(img0.axisof(a) for a in dims)
+    f0 = xp.sqrt(pw0)
+    f1 = xp.sqrt(pw1)
+    f0 -= xp.mean(f0, axis=_dims, keepdims=True)
+    f1 -= xp.mean(f1, axis=_dims, keepdims=True)
+    if mask is None:
+        corr = _zncc(f0, f1, _dims)
+    else:
+        if img0.ndim > mask.ndim:
+            mask = add_axes(img0.axes, img0.shape, mask, mask.axes)
+        corr = _masked_zncc(f0, f1, _dims, xp.asarray(np.asarray(mask)))
+    return _make_corr_output(xp.asnumpy(corr), img0, "fourier_zncc", squeeze, dims)
 
 @_docs.write_docs
 def pcc_maximum(
@@ -344,7 +366,7 @@ def pcc_maximum(
     max_shifts: int | tuple[int, ...] | None = None
 ) -> np.ndarray:
     """
-    Calculate lateral shift between two images. 
+    Calculate lateral shift between two images using phase cross correlation.
     
     Same as ``skimage.registration.phase_cross_correlation`` but some additional parameters 
     are supported.
@@ -363,23 +385,52 @@ def pcc_maximum(
     np.ndarray
         Shift in pixel.
     """    
+    return pcc_maximum_with_corr(img0, img1, mask, upsample_factor, max_shifts)[0]
+
+@_docs.write_docs
+def pcc_maximum_with_corr(
+    img0: ImgArray, 
+    img1: ImgArray, 
+    mask: ImgArray | None = None, 
+    upsample_factor: int = 10,
+    max_shifts: int | tuple[int, ...] | None = None
+) -> np.ndarray:
+    """
+    Calculate lateral shift between two images using phase cross correlation.
+    
+    Same as ``skimage.registration.phase_cross_correlation`` but some additional parameters 
+    are supported.
+
+    Parameters
+    ----------
+    {inputs_of_correlation}
+    upsample_factor : int, default is 10
+        Up-sampling factor when calculating phase cross correlation.
+    max_shifts : int, tuple of int, optional
+        Maximum shifts in each dimension. If a single integer is given, it is interpreted 
+        as maximum shifts in all dimensions. No upper bound of shifts if not given.
+    
+    Returns
+    -------
+    np.ndarray and float
+        Shift in pixel and phase cross correlation
+    """    
     if img0 is img1:
         return np.zeros(img0.ndim)
-    with Progress("pcc_maximum"):
-        img0, img1 = _check_inputs(img0, img1)
-        ft0 = img0.fft(dims=img0.axes)
-        ft1 = img1.fft(dims=img1.axes)
-        if mask is not None:
-            ft0[mask] = 0
-        if isinstance(max_shifts, (int, float)):
-            max_shifts = (max_shifts,) * img0.ndim
-        shift = subpixel_pcc(
-            xp.asarray(ft0.value), 
-            xp.asarray(ft1.value),
-            upsample_factor, 
-            max_shifts=max_shifts
-        )
-    return xp.asnumpy(shift)
+    img0, img1 = _check_inputs(img0, img1)
+    ft0 = img0.fft(dims=img0.axes)
+    ft1 = img1.fft(dims=img1.axes)
+    if mask is not None:
+        ft0[mask] = 0
+    if isinstance(max_shifts, (int, float)):
+        max_shifts = (max_shifts,) * img0.ndim
+    shift, pcc = subpixel_pcc(
+        xp.asarray(ft0.value), 
+        xp.asarray(ft1.value),
+        upsample_factor, 
+        max_shifts=max_shifts
+    )
+    return xp.asnumpy(shift), float(pcc)
 
 @_docs.write_docs
 def ft_pcc_maximum(
@@ -390,7 +441,7 @@ def ft_pcc_maximum(
     max_shifts: float | tuple[float, ...] | None = None
 ) -> np.ndarray:
     """
-    Calculate lateral shift between two images.
+    Calculate lateral shift between two images using phase cross correlation.
     
     This function takes Fourier transformed images as input. If you have to repetitively
     use a same template image, this function is faster.
@@ -401,28 +452,126 @@ def ft_pcc_maximum(
     upsample_factor : int, default is 10
         Up-sampling factor when calculating phase cross correlation.
     max_shifts : float, tuple of float, optional
-        Maximum shifts in each dimension. If a single scalar is given, it is interpreted as maximum shifts
-        in all dimensions. No upper bound of shifts if not given.
+        Maximum shifts in each dimension. If a single scalar is given, it is interpreted as
+        maximum shifts in all dimensions. No upper bound of shifts if not given.
 
     Returns
     -------
     np.ndarray
         Shift in pixel.
     """    
-    with Progress("ft_pcc_maximum"):
-        _check_dimensions(img0, img1)
-        if mask is not None:
-            img0 = img0.copy()
-            img0[mask] = 0
-        if isinstance(max_shifts, (int, float)):
-            max_shifts = (max_shifts,) * img0.ndim
-        shift = subpixel_pcc(
-            xp.asarray(img0.value), 
-            xp.asarray(img1.value),
-            upsample_factor,
-            max_shifts=max_shifts,
-        )
-    return xp.asnumpy(shift)
+    return ft_pcc_maximum_with_corr(img0, img1, mask, upsample_factor, max_shifts)[0]
+
+@_docs.write_docs
+def ft_pcc_maximum_with_corr(
+    img0: ImgArray,
+    img1: ImgArray, 
+    mask: ImgArray | None = None, 
+    upsample_factor: int = 10,
+    max_shifts: float | tuple[float, ...] | None = None
+) -> np.ndarray:
+    """
+    Calculate lateral shift between two images using phase cross correlation.
+    
+    This function takes Fourier transformed images as input. If you have to repetitively
+    use a same template image, this function is faster.
+
+    Parameters
+    ----------
+    {inputs_of_correlation}
+    upsample_factor : int, default is 10
+        Up-sampling factor when calculating phase cross correlation.
+    max_shifts : float, tuple of float, optional
+        Maximum shifts in each dimension. If a single scalar is given, it is interpreted as
+        maximum shifts in all dimensions. No upper bound of shifts if not given.
+
+    Returns
+    -------
+    np.ndarray and float
+        Shift in pixel and phase cross correlation.
+    """    
+    _check_dimensions(img0, img1)
+    if mask is not None:
+        img0 = img0.copy()
+        img0[mask] = 0
+    if isinstance(max_shifts, (int, float)):
+        max_shifts = (max_shifts,) * img0.ndim
+    shift, pcc = subpixel_pcc(
+        xp.asarray(img0.value), 
+        xp.asarray(img1.value),
+        upsample_factor,
+        max_shifts=max_shifts,
+    )
+    return xp.asnumpy(shift), float(pcc)
+
+@_docs.write_docs
+def pcc_landscape(
+    img0: ImgArray, 
+    img1: ImgArray,
+    max_shifts: int | tuple[int, ...] | None = None,
+):
+    """
+    Create landscape of phase cross correlation.
+
+    Parameters
+    ----------
+    {inputs_of_correlation}
+    max_shifts : float, tuple of float, optional
+        Maximum shifts in each dimension. If a single scalar is given, it is interpreted as
+        maximum shifts in all dimensions. No upper bound of shifts if not given.
+
+    Returns
+    -------
+    ImgArray
+        Landscape image.
+    """    
+    _check_dimensions(img0, img1)
+    if isinstance(max_shifts, (int, float)):
+        max_shifts = (max_shifts,) * img0.ndim
+    
+    ft0 = img0.fft(dims=img0.axes)
+    ft1 = img1.fft(dims=img1.axes)
+    landscape = draw_pcc_landscape(
+        xp.asarray(ft0.value), 
+        xp.asarray(ft1.value),
+        max_shifts=max_shifts
+    )
+    return ip_asarray(xp.asnumpy(landscape), axes=img1.axes)
+
+@_docs.write_docs
+def ft_pcc_landscape(
+    img0: ImgArray, 
+    img1: ImgArray,
+    max_shifts: int | tuple[int, ...] | None = None,
+):
+    """
+    Create landscape of phase cross correlation.
+
+    This function takes Fourier transformed images as input. If you have to repetitively
+    use a same template image, this function is faster.
+    
+    Parameters
+    ----------
+    {inputs_of_correlation}
+    max_shifts : float, tuple of float, optional
+        Maximum shifts in each dimension. If a single scalar is given, it is interpreted as
+        maximum shifts in all dimensions. No upper bound of shifts if not given.
+
+    Returns
+    -------
+    ImgArray
+        Landscape image.
+    """    
+    _check_dimensions(img0, img1)
+    if isinstance(max_shifts, (int, float)):
+        max_shifts = (max_shifts,) * img0.ndim
+
+    landscape = draw_pcc_landscape(
+        xp.asarray(img0.value), 
+        xp.asarray(img1.value),
+        max_shifts=max_shifts
+    )
+    return ip_asarray(xp.asnumpy(landscape), axes=img1.axes)
 
 @_docs.write_docs
 def polar_pcc_maximum(
@@ -447,21 +596,150 @@ def polar_pcc_maximum(
     float
         Rotation in degree
     """    
+    return polar_pcc_maximum_with_corr(img0, img1, upsample_factor, max_degree)[0]
+
+@_docs.write_docs
+def polar_pcc_maximum_with_corr(
+    img0: ImgArray,
+    img1: ImgArray,
+    upsample_factor: int = 10,
+    max_degree: int = None,
+) -> float:
+    """
+    Calculate rotational shift between two images using polar Fourier transformation.
+
+    Parameters
+    ----------
+    {inputs_of_correlation}
+    upsample_factor : int, default is 10
+        Up-sampling factor when calculating phase cross correlation.
+    max_degree : int, tuple of int, optional
+        Maximum rotation in degree.
+
+    Returns
+    -------
+    float and float
+        Rotation in degree and phase cross correlation
+    """    
     img0, img1 = _check_inputs(img0, img1)
     if img0.ndim != 2:
         raise TypeError("Currently only 2D image is supported.")
     if max_degree is None:
         max_degree = 180
     rmax = min(img0.shape)
-    with Progress("polar_pcc_maximum_2d"):
-        imgp = ip_asarray(xp.asnumpy(polar2d(img0, rmax, np.pi/180)))
-        imgrotp = ip_asarray(xp.asnumpy(polar2d(img1, rmax, np.pi/180)))
-        max_shifts = (max_degree, 1)
-        shift = pcc_maximum(imgp, imgrotp, upsample_factor=upsample_factor,
-                            max_shifts=max_shifts)
+    imgp = ip_asarray(xp.asnumpy(polar2d(img0, rmax, np.pi/180)))
+    imgrotp = ip_asarray(xp.asnumpy(polar2d(img1, rmax, np.pi/180)))
+    max_shifts = (max_degree, 1)
+    shift, pcc = pcc_maximum_with_corr(
+        imgp, imgrotp, upsample_factor=upsample_factor, max_shifts=max_shifts
+    )
     # Here, `shift` satisfies `img0.rotate(-shift[0]) == img1`
-    return shift[0]
+    return shift[0], pcc
 
+@_docs.write_docs
+def zncc_maximum(
+    img0: ImgArray, 
+    img1: ImgArray,
+    upsample_factor: int = 10,
+    max_shifts: int | tuple[int, ...] | None = None
+) -> np.ndarray:
+    """
+    Calculate lateral shift between two images using zero-mean normalized cross correlation.
+    
+    Similar to :func:`pcc_maximum`, this function can determine shift at sub-pixel precision.
+    Since ZNCC uses real space, this function performs better than PCC when the input images
+    have frequency loss.
+    Unlike :func:`zncc_maximum_with_corr`, this function only returns the optimal shift.
+    Parameters
+    ----------
+    {inputs_of_correlation}
+    upsample_factor : int, default is 10
+        Up-sampling factor when calculating cross correlation. Convolution image will be
+        up-sampled by third-order interpolation.
+    max_shifts : float, tuple of float, optional
+        Maximum shifts in each dimension. If a single scalar is given, it is interpreted as
+        maximum shifts in all dimensions. No upper bound of shifts if not given.
+    Returns
+    -------
+    np.ndarray
+        Shift in pixel .
+    """    
+    return zncc_maximum_with_corr(img0, img1, upsample_factor, max_shifts)[0]
+
+@_docs.write_docs
+def zncc_maximum_with_corr(
+    img0: ImgArray, 
+    img1: ImgArray,
+    upsample_factor: int = 10,
+    max_shifts: int | tuple[int, ...] | None = None
+) -> tuple[np.ndarray, float]:
+    """
+    Calculate lateral shift between two images using zero-mean normalized cross correlation.
+    
+    Similar to :func:`pcc_maximum`, this function can determine shift at sub-pixel precision.
+    Since ZNCC uses real space, this function performs better than PCC when the input images
+    have frequency loss.
+    Parameters
+    ----------
+    {inputs_of_correlation}
+    upsample_factor : int, default is 10
+        Up-sampling factor when calculating cross correlation. Convolution image will be
+        up-sampled by third-order interpolation.
+    max_shifts : float, tuple of float, optional
+        Maximum shifts in each dimension. If a single scalar is given, it is interpreted as
+        maximum shifts in all dimensions. No upper bound of shifts if not given.
+    Returns
+    -------
+    np.ndarray and float
+        Shift in pixel and ZNCC value.
+    """    
+    if img0 is img1:
+        return np.zeros(img0.ndim), 1.
+    img0, img1 = img0.astype(np.float32), img1.astype(np.float32)
+    img0z = img0 - img0.mean()
+    img1z = img1 - img1.mean()
+    if isinstance(max_shifts, (int, float)):
+        max_shifts = (max_shifts,) * img0.ndim
+    shift, zncc = subpixel_ncc(
+        xp.asarray(np.asarray(img0z)), 
+        xp.asarray(np.asarray(img1z)),
+        upsample_factor, 
+        max_shifts=max_shifts
+    )
+    return xp.asnumpy(shift), float(zncc)
+
+@_docs.write_docs
+def zncc_landscape(
+    img0: ImgArray, 
+    img1: ImgArray,
+    max_shifts: int | tuple[int, ...] | None = None,
+):
+    """
+    Create landscape of zero-mean normalized cross correlation.
+
+    Parameters
+    ----------
+    {inputs_of_correlation}
+    max_shifts : float, tuple of float, optional
+        Maximum shifts in each dimension. If a single scalar is given, it is interpreted as
+        maximum shifts in all dimensions. No upper bound of shifts if not given.
+
+    Returns
+    -------
+    ImgArray
+        Landscape image.
+    """    
+    img0, img1 = img0.astype(np.float32), img1.astype(np.float32)
+    img0z = img0 - img0.mean()
+    img1z = img1 - img1.mean()
+    if isinstance(max_shifts, (int, float)):
+        max_shifts = (max_shifts,) * img0.ndim
+    landscape = draw_ncc_landscape(
+        xp.asarray(np.asarray(img0z)), 
+        xp.asarray(np.asarray(img1z)),
+        max_shifts=max_shifts
+    )
+    return ip_asarray(xp.asnumpy(landscape), axes=img1.axes)
 
 @_docs.write_docs
 @dims_to_spatial_axes
@@ -535,6 +813,6 @@ def _make_corr_output(corr: np.ndarray, refimg: ImgArray, propname: str, squeeze
         corr = corr[()]
     else:
         corr = PropArray(corr, name=refimg.name, axes=complement_axes(dims, refimg.axes), 
-                        dirpath=refimg.dirpath, metadata=refimg.metadata, 
+                        source=refimg.source, metadata=refimg.metadata, 
                         propname=propname, dtype=np.float32)
     return corr
