@@ -10,10 +10,9 @@ from ..array_api import xp
 
 from ..axes import ImageAxesError
 from .axesop import complement_axes
-from ..utils.axesop import switch_slice
 
 if TYPE_CHECKING:
-    from ..arrays.bases import HistoryArray
+    from ..arrays.bases import MetaArray
 
 __all__ = ["imwrite", 
            "memmap",
@@ -34,27 +33,18 @@ def open_tif(path: str, return_img: bool = False, memmap: bool = False):
     
         pagetag = series0.pages[0].tags
         
-        hist = []
         if ijmeta is None:
             ijmeta = {}
         
         ijmeta.pop("ROI", None)
         
-        if "Info" in ijmeta.keys():
-            try:
-                infodict = load_json(ijmeta["Info"])
-            except:
-                infodict = {}
-            if "impyhist" in infodict.keys():
-                hist = infodict["impyhist"].split("->")
-        
         try:
             axes = series0.axes.lower()
         except:
             axes = None
         
         tags = {v.name: v.value for v in pagetag.values()}
-        out = {"axes": axes, "ijmeta": ijmeta, "history": hist, "tags": tags}
+        out = {"axes": axes, "ijmeta": ijmeta, "tags": tags}
         if return_img:
             if memmap:
                 out["image"] = tif.asarray(out="memmap")
@@ -86,7 +76,7 @@ def open_mrc(path: str, return_img: bool = False, memmap: bool = False):
         tags["XResolution"] = [1, mrc.voxel_size.x/10]
         tags["YResolution"] = [1, mrc.voxel_size.y/10]
         
-        out = {"axes": axes, "ijmeta": ijmeta, "history": [], "tags": tags}
+        out = {"axes": axes, "ijmeta": ijmeta, "tags": tags}
         if return_img:
             out["image"] = mrc.data
     
@@ -117,9 +107,9 @@ def open_img(path, memmap: bool = False):
         from skimage import io
         img = io.imread(path)
         if fext in (".png", ".jpg") and img.ndim == 3 and img.shape[-1] <= 4:
-            meta = {"axes": "yxc", "ijmeta": {}, "history": []}
+            meta = {"axes": "yxc", "ijmeta": {}}
         else:
-            meta = {"axes": None, "ijmeta": {}, "history": []}
+            meta = {"axes": None, "ijmeta": {}}
     
     return meta, img
 
@@ -150,7 +140,7 @@ def get_scale_from_meta(meta: dict):
     return scale
 
 
-def get_imsave_meta_from_img(img: HistoryArray, update_lut=True):
+def get_imsave_meta_from_img(img: MetaArray, update_lut=True):
     metadata = img.metadata.copy()
     if update_lut:
         lut_min, lut_max = np.percentile(img, [1, 99])
@@ -167,12 +157,10 @@ def get_imsave_meta_from_img(img: HistoryArray, update_lut=True):
     else:
         metadata["spacing"] = img.scale["x"]
         
-    # add history to Info
     try:
         info = load_json(metadata["Info"])
     except:
         info = {}
-    info["impyhist"] = "->".join([img.name] + img.history)
     metadata["Info"] = str(info)
     # set axes in tiff metadata
     metadata["axes"] = str(img.axes).upper()
@@ -182,7 +170,7 @@ def get_imsave_meta_from_img(img: HistoryArray, update_lut=True):
     return dict(imagej=True, resolution=res, metadata=metadata)
 
 
-def save_tif(path: str, img: HistoryArray):
+def save_tif(path: str, img: MetaArray):
     rest_axes = complement_axes(img.axes, "tzcyx")
     new_axes = ""
     for a in img.axes:
@@ -208,7 +196,7 @@ def save_tif(path: str, img: HistoryArray):
     imwrite(path, img, **imsave_kwargs)
 
 
-def save_mrc(path: str, img: HistoryArray):
+def save_mrc(path: str, img: MetaArray):
     if img.scale_unit and img.scale_unit != "nm":
         raise ValueError(
             f"Scale unit {img.scale_unit} is not supported. Convert to nm instead."
@@ -230,3 +218,30 @@ def save_mrc(path: str, img: HistoryArray):
         with mrcfile.new(path) as mrc:
             mrc.set_data(img.value)
             mrc.voxel_size = tuple(np.array(img.scale)[::-1] * 10)
+
+def memmap_tif(data, path: str, shape: tuple[int, ...], dtype, **kwargs):
+    mmap = memmap(str(path), shape=shape, dtype=dtype, **kwargs)
+    mmap[:] = data
+    mmap.flush()
+    return None
+
+def memmap_mrc(data, path: str, shape: tuple[int, ...], dtype, **kwargs):
+    import mrcfile
+    if dtype == "int8":
+        mode = 0
+    elif dtype == "int16":
+        mode = 1
+    elif dtype == "float32":
+        mode = 2
+    elif dtype == "complex64":
+        mode = 4
+    elif dtype == "uint16":
+        mode = 6
+    else:
+        raise TypeError(f"Unsupported dtype {dtype}.")
+    mrc_mmap = mrcfile.new_mmap(path, shape, mrc_mode=mode, overwrite=True)
+    mrc_mmap.voxel_size = kwargs["metadata"]["spacing"] * 10  # nm -> ang
+    mrc_mmap.data[:] = data
+    mrc_mmap.flush()
+    return None
+    
\ No newline at end of file
